#
# spec file for package mariadb-connector-c
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%bcond_with sqlite3
%define sover 2
%define libname libmariadb

%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif

Name:           mariadb-connector-c
Version:        2.3.2
Release:        1.1
License:        LGPL-2.1+
Summary:        MariaDB connector in C
Url:            https://github.com/MariaDB/mariadb-connector-c
Group:          Development/Libraries/C and C++
Source:         https://downloads.mariadb.com/Connectors/c/connector-c-2.3.2/%{name}-%{version}-src.tar.gz
Source1:        https://downloads.mariadb.com/Connectors/c/connector-c-2.3.2/%{name}-%{version}-src.tar.gz.asc
# Imported from keyserver based on keyid @ https://mariadb.com/kb/en/mariadb-enterprise/mariadb-enterprise-installation-guide/
Source2:        mariadb.keyring
Patch1:         mariadb-connector-c-2.3.1_unresolved_symbols.patch
Patch2:         bigendian_type_fixes.patch
Patch3:         absolute_path_fix.patch
Patch4:         private_library.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(krb5-gssapi)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
%if %{with sqlite3}
BuildRequires:  sqlite3-devel
%endif

%description
MariaDB Connector is used to connect applications developed in
C or C++ to MariaDB and MySQL databases.

%package -n %{libname}%{sover}
Group:          System/Libraries
Summary:        MariaDB connector in C

%description -n %{libname}%{sover}
MariaDB Connector is used to connect applications developed in
C or C++ to MariaDB and MySQL databases.

This package holds the runtime components.

%package -n %{libname}_plugins
Group:          SystemLibraries
Summary:        Plugins for the MariaDB C Connector

%description -n %{libname}_plugins
MariaDB Connector is used to connect applications developed in
C or C++ to MariaDB and MySQL databases.

This package holds MariaDB library plugins.

%package -n %{libname}private
Group:          System/Libraries
Summary:        Additional internal libraries for the MariaDB C Connector

%description -n %{libname}private
MariaDB Connector is used to connect applications developed in
C or C++ to MariaDB and MySQL databases.

This package holds the runtime components with private API.

%package -n %{libname}-devel
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{sover} = %{version}
Requires:       pkgconfig(openssl)
Summary:        Development files for the MariaDB Connector C API

%description -n %{libname}-devel
MariaDB Connector is used to connect applications developed in
C or C++ to MariaDB and MySQL databases.

This package holds the development files.

%prep
%setup -q -n %{name}-%{version}-src
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
%cmake \
  %if %{with sqlite3}
  -DWITH_SQLITE:BOOL=ON \
  %endif
  -DWITH_EXTERNAL_ZLIB:BOOL=ON \
  -DPLUGIN_INSTALL_DIR:STRING=%{_libdir}/mariadb/plugin/ \
  -DMYSQL_UNIX_ADDR:STRING=%{_rundir}/mysql/mysql.sock
make %{?_smp_mflags}

%install
%cmake_install

rm %{buildroot}%{_includedir}/mariadb/CMakeLists.txt \
   %{buildroot}%{_includedir}/mariadb/*.am

rm %{buildroot}%{_libdir}/mariadb/*.a
rm %{buildroot}%{_libdir}/*.a

%files -n %{libname}%{sover}
%defattr(-,root,root)
%{_libdir}/libmariadb.so.%{sover}

%files -n %{libname}_plugins
%dir %{_libdir}/mariadb/
%dir %{_libdir}/mariadb/plugin/
%{_libdir}/mariadb/plugin/dialog.so
%{_libdir}/mariadb/plugin/mysql_clear_password.so

%files -n %{libname}private
%{_libdir}/libmariadbprivate.so

%files -n %{libname}-devel
%defattr(-,root,root)
%{_bindir}/mariadb_config
%{_includedir}/mariadb/
%{_libdir}/libmariadb.so
%{_libdir}/mariadb/libmysqlclient.so
%{_libdir}/mariadb/libmysqlclient_r.so

%post   -n %{libname}%{sover} -p /sbin/ldconfig
%post   -n %{libname}private -p /sbin/ldconfig
%postun -n %{libname}%{sover} -p /sbin/ldconfig
%postun -n %{libname}private -p /sbin/ldconfig

%changelog
* Mon Apr  3 2017 jengelh@inai.de
- Update descriptions and RPM groups
* Wed Mar 29 2017 adam.majer@suse.de
- Set proper MySQL socket path for localhost connections
* Thu Mar 23 2017 adam.majer@suse.de
- Update to version 2.3.2
  * Plugin API interface change: Changed the interface of
    authentication plugins, allowing plugins from C/C 3.0
    (like GSSAPI/Kerberos plugin)
  * CONC-205: Any field going after a TEXT field in the selecion
    list is fetched incorrectly (prepared statements)
  * CONC-198: Can't use more than one statement per connection
  * CONC-223: Add client support for missing collations
  * MDEV-10894: big endian conversion
  * fixed packet_length in dialog plugin
  * fixed include of my_stmt.h
  * fixed wrong behavior of read_timeout
  * fixed timeout for non-blocking operations
  * fixed output for plugindir in mariadb_config
  * removed extra check for non binary result types in fetch_bin
    (prepared statements)
- mariadb.keyring: add MariaDB Enterprise signing key
- bigendian_type_fixes.patch: fix build failure on Big endien
- absolute_path_fix.patch:
  * remove ugly paths in mariadb_config
  * list correct include paths
- private_library.patch: shared library with exported private
  symbols in place of a static library
- mariadb-connector-c-2.3.1_unresolved_symbols.patch: add missing
  library to link requirements.
* Mon Aug 22 2016 mrueckert@suse.de
- initial package
